@@ -1,11 +1,11 @@
 /* functions.m
  * Common Cenon functions
  *
- * Copyright (C) 1996-2005 by vhf interservice GmbH
+ * Copyright (C) 1996-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-25
- * modified: 2005-01-04
+ * modified: 2006-02-26
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -61,7 +61,7 @@ NSString *userLibrary(void)
     return [[NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, YES) objectAtIndex:0]
             stringByAppendingPathComponent:APPNAME];
 #else
-    return [NSString stringWithFormat:@"%@%@", vhfHomeDirectory(), HOMELIBRARY];
+    return vhfPathWithPathComponents(NSHomeDirectory(), HOMELIBRARY, nil);
 #endif
 }
 
@@ -71,7 +71,7 @@ NSString *localBundlePath(void)
     return [[NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSLocalDomainMask, YES) objectAtIndex:0]
             stringByAppendingPathComponent:BUNDLEFOLDER];
 #else
-    return [NSString stringWithFormat:@"/LocalLibrary/%@", BUNDLEFOLDER];
+    return vhfPathWithPathComponents(@"/LocalLibrary", BUNDLEFOLDER, nil);
 #endif
 }
 NSString *systemBundlePath(void)
@@ -80,7 +80,7 @@ NSString *systemBundlePath(void)
     return [[NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSSystemDomainMask, YES) objectAtIndex:0]
             stringByAppendingPathComponent:BUNDLEFOLDER];
 #else	// OpenStep
-    return [NSString stringWithFormat:@"/NextLibrary/%@", BUNDLEFOLDER];
+    return vhfPathWithPathComponents(@"/NextLibrary", BUNDLEFOLDER, nil);
 #endif
 }
 NSString *userBundlePath(void)
@@ -89,7 +89,7 @@ NSString *userBundlePath(void)
     return [[NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, YES) objectAtIndex:0]
             stringByAppendingPathComponent:BUNDLEFOLDER];
 #else
-    return [NSString stringWithFormat:@"%@Library/%@", vhfHomeDirectory(), BUNDLEFOLDER];
+    return vhfPathWithPathComponents(NSHomeDirectory(), @"Library", BUNDLEFOLDER, nil);
 #endif
 }
 
@@ -99,7 +99,7 @@ NSString *userBundlePath(void)
  * Search the folder 'path' in all possible directories.
  *
  * begin:    1993-01-17
- * modified: 2004-03-29
+ * modified: 2005-11-16 (appendPathComponent)
  *
  * popup	the popup button
  * folder	the folder
@@ -137,7 +137,7 @@ void fillPopup(NSPopUpButton *popup, NSString *folder, NSString *ext, int remove
             path = userLibrary();
         else
             break;
-        path = [path stringByAppendingFormat:@"/%@", folder];
+        path = [path stringByAppendingPathComponent:folder];
 
         array = [defaultManager directoryContentsAtPath:path];
         cnt = [array count];
@@ -161,6 +161,26 @@ void fillPopup(NSPopUpButton *popup, NSString *folder, NSString *ext, int remove
         [popup selectItemAtIndex:selectedIx];
 }
 
+BOOL vhfUpdateMenuItem(id <NSMenuItem> menuItem, NSString *zeroItem, NSString *oneItem, BOOL state)
+{
+    if (state)
+    {
+        if ([menuItem tag] != 0)
+        {
+            [menuItem setTitleWithMnemonic:zeroItem];
+            [menuItem setTag:0];
+            [menuItem setEnabled:NO];	// causes it to get redrawn
+        }
+    }
+    else if ([menuItem tag] != 1)
+    {
+        [menuItem setTitleWithMnemonic:oneItem];
+        [menuItem setTag:1];
+        [menuItem setEnabled:NO];	// causes it to get redrawn
+    }
+    return YES;
+}
+
 NSDictionary *dictionaryFromFolder(NSString *folder, NSString *name)
 {   NSDictionary	*dict;
     int			i;
@@ -168,15 +188,15 @@ NSDictionary *dictionaryFromFolder(NSString *folder, NSString *name)
     for (i=0;  ;i++)
     {   NSString	*path;
 
-        if (!i)		// application directory
-            path = [[NSBundle mainBundle] bundlePath];
+        if (!i)		// application resource directory
+            path = [[NSBundle mainBundle] resourcePath];
         else if (i==1)	// local library
             path = localLibrary();
         else if (i==2)	// user local library
             path = userLibrary();
         else
             break;
-        path = [path stringByAppendingFormat:@"/%@/%@", folder, name];
+        path = vhfPathWithPathComponents(path, folder, name, nil);
 
         if ( (dict = [NSDictionary dictionaryWithContentsOfFile:path]) )
             return dict;
